@@ -1,4 +1,5 @@
 import re
+
 import pandas as pd
 
 __all__ = [
@@ -11,6 +12,7 @@ _wsdedup = re.compile(r"\s+")
 _usdedup = re.compile(r"__+")
 _rmpunc = re.compile(r"[,.()&$/+-]+")
 
+
 # 63 seems to be a common max column name length
 def sql_compliant_name(name, maxlen=63):
     if isinstance(name, list):
@@ -27,24 +29,26 @@ def sql_compliant_name(name, maxlen=63):
     w = w.replace("source", "src")
     w = w.replace("distribution", "dist")
     # these are common in the sample names but unsure of standard abbv
-    #w = w.replace("inference", "inf")
-    #w = w.replace("emissions", "emis")
-    #w = w.replace("intensity", "int")
-    #w = w.replace("reported", "rep")
-    #w = w.replace("revenue", "rev")
-    w = w[:maxlen] 
+    # w = w.replace("inference", "inf")
+    # w = w.replace("emissions", "emis")
+    # w = w.replace("intensity", "int")
+    # w = w.replace("reported", "rep")
+    # w = w.replace("revenue", "rev")
+    w = w[:maxlen]
     return w
 
+
 def enforce_sql_column_names(df, inplace=False, maxlen=63):
     if not isinstance(df, pd.DataFrame):
         raise ValueError("df must be a pandas DataFrame")
     icols = df.columns.to_list()
     ocols = sql_compliant_name(icols, maxlen=maxlen)
-    if (len(set(ocols)) < len(ocols)):
+    if len(set(ocols)) < len(ocols):
         raise ValueError("remapped column names were not unique!")
     rename_map = dict(list(zip(icols, ocols)))
     return df.rename(columns=rename_map, inplace=inplace)
 
+
 def enforce_partition_column_order(df, pcols, inplace=False):
     if not isinstance(df, pd.DataFrame):
         raise ValueError("df must be a pandas DataFrame")
